''********************************************
''*  ADS7822P object V1.0                    *
''*  (C) 2007 William Henning                *
''*  http://www.mikronauts.com               *
''********************************************
''
'' This object provides an easy interface to the ADS7822P Analog to Digital converter.
''
'' The ADS7822P is a 12 bit ADC capable of 200k samples per second while consuming only
'' 1.6mW, and it is available in a nice friendly DIP-8 package. It will quite happily
'' work with a 3.3V supply so it is very Propeller friendly.  
''
'' The data sheet is available at:
''
''      http://focus.ti.com/docs/prod/folders/print/ads7822.html
''
'' The chip is VERY easy to get working; this version of the object provides three methods:
''
'' init(basepin)
''
''      Initialize the indices to the DATA, CLOCK and CHIP_SELECT pins
''
''      basepin         DATA line of the A/D converter
''      basepin+1       CLOCK line
''      basepin+2       CHIP_SELECT for the A/D converter
''
'' ain12
''
''      starts conversion, and retrieves result; returns 12 bit value
''
'' fain9
''
''      'fast' analog in; inlines code and only returns the nine most significant bits
''      in order to do the conversion faster
''
'' I will be maintaining this object on my mikronauts.com site; there will be an assembly
'' version for high data rate capture soon, as well as additional input channels via a
'' multiplexer.
''
'' Everyone, especually Parallax, may use this object as they see fit.
''
'' William Henning
'' http://www.mikronauts.com
''

VAR
  word sCS
  word sCLK
  word sDAT

PUB init(p)

  sDAT:=p
  sCLK:=p+1
  sCS:=p+2

  dira[sCS]~~
  dira[sCLK]~~
  outa[sCS]~~

PUB ain12 : out | s
    out:=0
    outa[sCS]~
    repeat s from 0 to 2
      outa[sCLK]~~
      outa[sCLK]~
    repeat s from 0 to 11
      outa[sCLK]~~
      out += out+ina[sDAT]
      outa[sCLK]~
    outa[sCS]~~

PUB fain9 : val ' only picks up 9 bits, inlined for speed
    val:=0
    outa[sCS]~

    outa[sCLK]~~
    outa[sCLK]~

    outa[sCLK]~~
    outa[sCLK]~

    outa[sCLK]~~
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCLK]~~
    val += val+ina[sDAT]
    outa[sCLK]~

    outa[sCS]~~

        